@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "clojure-mode-extra-font-locking" "5.21.0"
+(define-package "clojure-mode-extra-font-locking" "5.22.0"
   "Extra font-locking for Clojure mode."
-  '((clojure-mode "3.0"))
+  '((clojure-mode "5.22.0"))
   :url "https://github.com/clojure-emacs/clojure-mode"
-  :commit "f1cd680918d6e3c28247b54fb199e186ef9cfd9d"
-  :revdesc "f1cd680918d6"
+  :commit "6314697ed8042db9341a11d1a330c305a3c36f37"
+  :revdesc "6314697ed804"
   :keywords '("languages" "lisp")
   :authors '(("Bozhidar Batsov" . "bozhidar@batsov.dev"))
   :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
